==> members-facade-threetree-1.0-20250507.091821-44-sources.jar: com/bizvane/members/facade/models/bo/MemberOpenCardReq.java <==
package com.bizvane.members.facade.models.bo;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.util.Date;

@Data
public class MemberOpenCardReq {

    @NotNull
    private Long sysBrandId;

    @NotBlank
    private String offlineOrgCode;

    @NotBlank
    private String externalId;

    @NotBlank
    private String phone;//	是	string	手机号

    // 会员等级code,如果为空则使用type计算
    private String levelCode;

    // 会员类型：1-潜客，5-专业师傅，10-消费者，15设计师，20分销商
    @NotNull
    private Integer type;

    @NotNull
    private String channelCode;// source	是	int	会员注册渠道 : 1.POS(门店) 2.官网3.商城 4.微信 5.天猫 6.其他

    private String sourceCode;

    private Long sysCompanyId;

    private String cardNo;//	是	string	会员卡号
    private String name;    //否	string	会员名称
    private Integer sex;    //否	int	性别 : 1.女 2.男 3.未知
    private String province;//	否	string	省
    private String city;//	否	string	市
    private String county;//	否	string	区
    private String address;//	否	string	会员详细地址
    private String remark;//	否	string	备注
    private String email;//	否	string	会员邮箱
    private String idCard;//	否	string	会员身份证号
    private String birthday;//	否	string	会员生日 格式 : yyyy-mm-dd
    private String storeCode;//	否	string	注册门店code,如果为空则默认按照中台配置的会员卡体系为准

    //guideCode
    private String guideCode;//否 string 导购code,如果为空则默认按照中台配置的会员卡体系为准

    private Integer points;//	否	int	会员可用积分,如果为空则默认为0

    private Date openCardTime;

    /**
     * 服务导购
     * */
    private String serviceGuideCode;

    /**
     * 服务导购电话
     * */
    @ApiModelProperty(value = "服务导购电话", name = "serviceGuidePhone",notes="根据电话查询导购信息")
    private String serviceGuidePhone;

    /**
     * 服务门店
     * */
    private String serviceStoreCode;

    /**
     * 邀请人会员手机号
     */
    private String inviterPhone;

    /**
     * 自定义属性json串 {"extendOfflineCode1":"value1","extendOfflineCode2":"value2"}
     */
    private String extendProperty;

    private String sourceWay;

    @ApiModelProperty(value = "微信openId", name = "wxOpenId")
    private String wxOpenId;

    @ApiModelProperty(value = "微信UnionId", name = "wxUnionId")
    private String wxUnionId;

}

==> members-facade-threetree-1.0-20250528.055044-53-sources.jar: com/bizvane/members/facade/models/bo/MemberOpenCardReq.java <==
package com.bizvane.members.facade.models.bo;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.util.Date;

@Data
public class MemberOpenCardReq {

    @NotNull
    private Long sysBrandId;

    @NotBlank
    private String offlineOrgCode;

    @NotBlank
    private String externalId;

    @NotBlank
    private String phone;//	是	string	手机号

    // 会员等级code,如果为空则使用type计算
    private String levelCode;

    // 会员类型：1-潜客，5-专业师傅，10-消费者，15设计师，20分销商，25-物业会员
    @NotNull
    private Integer type;

    @NotNull
    private String channelCode;// source	是	int	会员注册渠道 : 1.POS(门店) 2.官网3.商城 4.微信 5.天猫 6.其他

    private String sourceCode;

    private Long sysCompanyId;

    private String cardNo;//	是	string	会员卡号
    private String name;    //否	string	会员名称
    private Integer sex;    //否	int	性别 : 1.女 2.男 3.未知
    private String province;//	否	string	省
    private String city;//	否	string	市
    private String county;//	否	string	区
    private String address;//	否	string	会员详细地址
    private String remark;//	否	string	备注
    private String email;//	否	string	会员邮箱
    private String idCard;//	否	string	会员身份证号
    private String birthday;//	否	string	会员生日 格式 : yyyy-mm-dd
    private String storeCode;//	否	string	注册门店code,如果为空则默认按照中台配置的会员卡体系为准

    //guideCode
    private String guideCode;//否 string 导购code,如果为空则默认按照中台配置的会员卡体系为准

    private Integer points;//	否	int	会员可用积分,如果为空则默认为0

    private Date openCardTime;

    /**
     * 服务导购
     * */
    private String serviceGuideCode;

    /**
     * 服务导购电话
     * */
    @ApiModelProperty(value = "服务导购电话", name = "serviceGuidePhone",notes="根据电话查询导购信息")
    private String serviceGuidePhone;

    /**
     * 服务门店
     * */
    private String serviceStoreCode;

    /**
     * 邀请人会员手机号
     */
    private String inviterPhone;

    /**
     * 自定义属性json串 {"extendOfflineCode1":"value1","extendOfflineCode2":"value2"}
     */
    private String extendProperty;

    private String sourceWay;

    @ApiModelProperty(value = "微信openId", name = "wxOpenId")
    private String wxOpenId;

    @ApiModelProperty(value = "微信UnionId", name = "wxUnionId")
    private String wxUnionId;

}
